==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/lv-LV/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Pielāgotie lauki',
    'manage'                    => 'Pārvaldīt',
    'field'		                => 'Lauks',
    'about_fieldsets_title'		=> 'Par lauka laukiem',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Šifrējiet šī lauka vērtību datu bāzē',
    'encrypt_field_help'      => 'BRĪDINĀJUMS: lauka šifrēšana padara to neizpētītu.',
    'encrypted'      	        => 'Šifrēts',
    'fieldset'      	        => 'Lauka laukums',
    'qty_fields'      	      => 'Daudzi lauki',
    'fieldsets'      	        => 'Lauka lauki',
    'fieldset_name'           => 'Lauka nosaukums',
    'field_name'              => 'Lauka nosaukums',
    'field_values'            => 'Lauka vērtības',
    'field_values_help'       => 'Pievienot izvēles iespējas, pa vienai katrā rindiņā. Tukšās rindas, izņemot pirmo rindu, tiks ignorētas.',
    'field_element'           => 'Veidlapas elements',
    'field_element_short'     => 'Elements',
    'field_format'            => 'Formāts',
    'field_custom_format'     => 'Pielāgotais formāts',
    'field_custom_format_help'     => 'Šajā laukā var izmantot regulāro izteiksmi, lai pārbaudītu. Tai ir jāsākas ar "regex:". Piemēram, lai pārbaudītu, ka pielāgotais lauks satur derīgu IMEI (15 cipari), būtu jāizmanto vērtība <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligāts',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Izmantoti modeļi',
    'order'   		            => 'Pasūtījums',
    'create_fieldset'         => 'Jauns lauka laukums',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Jauna pielāgota lauks',
    'create_field_title' => 'Izveidot jaunu pielāgoto lauku',
    'value_encrypted'      	        => 'Šī lauka vērtība ir šifrēta datu bāzē. Tikai admin lietotāji varēs apskatīt atšifrēto vērtību',
    'show_in_email'     => 'Vai iekļaut šī lauka vērtību lietotājiem nosūtītajos e-pasta paziņojumos? Šifrētie lauki nevar būt iekļauti e-pasta ziņojumos',
    'show_in_email_short'     => 'Include in emails.',
    'help_text' => 'Palīdzības teksts',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Pārkārtot',
    'db_field' => 'DB lauks',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'Šai vērtībai ir jābūt unikālai starp visiem pamatlīdzekļiem',
    'unique' => 'Unikāls',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lv-LV/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Pielāgotie lauki',
    'manage'                    => 'Pārvaldīt',
    'field'		                => 'Lauks',
    'about_fieldsets_title'		=> 'Par lauka laukiem',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Šifrējiet šī lauka vērtību datu bāzē',
    'encrypt_field_help'      => 'BRĪDINĀJUMS: lauka šifrēšana padara to neizpētītu.',
    'encrypted'      	        => 'Šifrēts',
    'fieldset'      	        => 'Lauka laukums',
    'qty_fields'      	      => 'Daudzi lauki',
    'fieldsets'      	        => 'Lauka lauki',
    'fieldset_name'           => 'Lauka nosaukums',
    'field_name'              => 'Lauka nosaukums',
    'field_values'            => 'Lauka vērtības',
    'field_values_help'       => 'Pievienot izvēles iespējas, pa vienai katrā rindiņā. Tukšās rindas, izņemot pirmo rindu, tiks ignorētas.',
    'field_element'           => 'Veidlapas elements',
    'field_element_short'     => 'Elements',
    'field_format'            => 'Formāts',
    'field_custom_format'     => 'Pielāgotais formāts',
    'field_custom_format_help'     => 'Šajā laukā var izmantot regulāro izteiksmi, lai pārbaudītu. Tai ir jāsākas ar "regex:". Piemēram, lai pārbaudītu, ka pielāgotais lauks satur derīgu IMEI (15 cipari), būtu jāizmanto vērtība <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligāts',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Izmantoti modeļi',
    'order'   		            => 'Pasūtījums',
    'create_fieldset'         => 'Jauns lauka laukums',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Jauna pielāgota lauks',
    'create_field_title' => 'Izveidot jaunu pielāgoto lauku',
    'value_encrypted'      	        => 'Šī lauka vērtība ir šifrēta datu bāzē. Tikai admin lietotāji varēs apskatīt atšifrēto vērtību',
    'show_in_email'     => 'Vai iekļaut šī lauka vērtību lietotājiem nosūtītajos e-pasta paziņojumos? Šifrētie lauki nevar būt iekļauti e-pasta ziņojumos',
    'show_in_email_short' => 'Include in emails',
    'help_text' => 'Palīdzības teksts',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Pārkārtot',
    'db_field' => 'DB lauks',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'Šai vērtībai ir jābūt unikālai starp visiem pamatlīdzekļiem',
    'unique' => 'Unikāls',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
